@@ -2,11 +2,19 @@
 #
 # This file is part of duplicity.
 #
-# duplicity is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA
-# 02139, USA; either version 2 of the License, or (at your option) any
-# later version; incorporated herein by reference.
+# Duplicity is free software; you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; either version 2 of the License, or (at your
+# option) any later version.
+#
+# Duplicity is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with duplicity; if not, write to the Free Software Foundation,
+# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 """Functions for patching of directories"""
 
@@ -18,6 +26,7 @@ from lazy import *
 
 class PatchDirException(Exception): pass
 
+
 def Patch(base_path, difftar_fileobj):
 	"""Patch given base_path and file object containing delta"""
 	diff_tarfile = tarfile.TarFile("arbitrary", "r", difftar_fileobj)
@@ -119,18 +128,22 @@ def get_index_from_tarinfo(tarinfo):
 					  re.subn("^multivol_(diff|snapshot)/(.*)/[0-9]+$",
 							  "\\2", tarinfo.name)
 				if num_subs != 1:
-					raise DiffDirException("Unrecognized diff entry %s" %
-										   (tarinfo.name,))
+					raise PatchDirException("Unrecognized diff entry %s" %
+											(tarinfo.name,))
 			else:
 				difftype = prefix[:-1] # strip trailing /
 				name = tarinfo.name[len(prefix):]
 				if name.endswith("/"): name = name[:-1] # strip trailing /'s
 				multivol = 0
 			break
-	else: raise DiffDirException("Unrecognized diff entry %s" %
+	else: raise PatchDirException("Unrecognized diff entry %s" %
 								 (tarinfo.name,))
 	if name == ".": index = ()
-	else: index = tuple(name.split("/"))
+	else:
+		index = tuple(name.split("/"))
+		if '..' in index:
+			raise PatchDirException("Tar entry %s contains '..'.  Security "
+									"violation" % (tarinfo.name,))
 	return (index, difftype, multivol)
 
 
